[PATCH] D38957: AMDGPU: Rename MaxFlatWorkgroupSize to MaxFlatWorkGroupSize for consistency

Konstantin Zhuravlyov via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Mon Oct 16 09:17:53 PDT 2017


kzhuravl created this revision.
Herald added subscribers: tpr, dstuttard, yaxunl, nhaehnle, wdng.

It seems like all other places use WorkGroup (attributes, function names, etc.)


https://reviews.llvm.org/D38957

Files:
  docs/AMDGPUUsage.rst
  include/llvm/Support/AMDGPUKernelDescriptor.h
  include/llvm/Support/AMDGPUMetadata.h
  lib/Support/AMDGPUMetadata.cpp


Index: lib/Support/AMDGPUMetadata.cpp
===================================================================
--- lib/Support/AMDGPUMetadata.cpp
+++ lib/Support/AMDGPUMetadata.cpp
@@ -142,8 +142,8 @@
                     MD.mNumSGPRs, uint16_t(0));
     YIO.mapOptional(Kernel::CodeProps::Key::NumVGPRs,
                     MD.mNumVGPRs, uint16_t(0));
-    YIO.mapOptional(Kernel::CodeProps::Key::MaxFlatWorkgroupSize,
-                    MD.mMaxFlatWorkgroupSize, uint32_t(0));
+    YIO.mapOptional(Kernel::CodeProps::Key::MaxFlatWorkGroupSize,
+                    MD.mMaxFlatWorkGroupSize, uint32_t(0));
     YIO.mapOptional(Kernel::CodeProps::Key::IsDynamicCallStack,
                     MD.mIsDynamicCallStack, false);
     YIO.mapOptional(Kernel::CodeProps::Key::IsXNACKEnabled,
Index: include/llvm/Support/AMDGPUKernelDescriptor.h
===================================================================
--- include/llvm/Support/AMDGPUKernelDescriptor.h
+++ include/llvm/Support/AMDGPUKernelDescriptor.h
@@ -109,7 +109,7 @@
 struct KernelDescriptor final {
   uint32_t GroupSegmentFixedSize;
   uint32_t PrivateSegmentFixedSize;
-  uint32_t MaxFlatWorkgroupSize;
+  uint32_t MaxFlatWorkGroupSize;
   uint64_t IsDynamicCallStack : 1;
   uint64_t IsXNACKEnabled : 1;
   uint64_t Reserved0 : 30;
Index: docs/AMDGPUUsage.rst
===================================================================
--- docs/AMDGPUUsage.rst
+++ docs/AMDGPUUsage.rst
@@ -1201,7 +1201,7 @@
                                                            registers used by
                                                            each work-item for
                                                            GFX6-GFX9
-     "MaxFlatWorkgroupSize"       integer                  Maximum flat
+     "MaxFlatWorkGroupSize"       integer                  Maximum flat
                                                            work-group size
                                                            supported by the
                                                            kernel in work-items.
@@ -1444,7 +1444,7 @@
                                                      then additional space must
                                                      be added to this value for
                                                      the call stack.
-     95:64   4 bytes MaxFlatWorkgroupSize            Maximum flat work-group
+     95:64   4 bytes MaxFlatWorkGroupSize            Maximum flat work-group
                                                      size supported by the
                                                      kernel in work-items.
      96      1 bit   IsDynamicCallStack              Indicates if the generated


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D38957.119166.patch
Type: text/x-patch
Size: 3956 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20171016/50b48bce/attachment.bin>


More information about the llvm-commits mailing list
Index: include/llvm/Support/AMDGPUMetadata.h
===================================================================
--- include/llvm/Support/AMDGPUMetadata.h
+++ include/llvm/Support/AMDGPUMetadata.h
@@ -238,8 +238,8 @@
 constexpr char NumSGPRs[] = "NumSGPRs";
 /// \brief Key for Kernel::CodeProps::Metadata::mNumVGPRs.
 constexpr char NumVGPRs[] = "NumVGPRs";
-/// \brief Key for Kernel::CodeProps::Metadata::mMaxFlatWorkgroupSize.
-constexpr char MaxFlatWorkgroupSize[] = "MaxFlatWorkgroupSize";
+/// \brief Key for Kernel::CodeProps::Metadata::mMaxFlatWorkGroupSize.
+constexpr char MaxFlatWorkGroupSize[] = "MaxFlatWorkGroupSize";
 /// \brief Key for Kernel::CodeProps::Metadata::mIsDynamicCallStack.
 constexpr char IsDynamicCallStack[] = "IsDynamicCallStack";
 /// \brief Key for Kernel::CodeProps::Metadata::mIsXNACKEnabled.
@@ -268,7 +268,7 @@
   /// \brief Total number of VGPRs used by a workitem. Optional.
   uint16_t mNumVGPRs = 0;
   /// \brief Maximum flat work-group size supported by the kernel. Optional.
-  uint32_t mMaxFlatWorkgroupSize = 0;
+  uint32_t mMaxFlatWorkGroupSize = 0;
   /// \brief True if the generated machine code is using a dynamically sized
   /// call stack. Optional.
   bool mIsDynamicCallStack = false;